Coverage report

# Coverage report: 85%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 493 | 75 | 0 | 85%
tictactoe/__init__ | 2 | 0 | 0 | 100%
tictactoe/celery_app | 7 | 0 | 0 | 100%
tictactoe/config | 8 | 0 | 0 | 100%
tictactoe/contest/__init__ | 0 | 0 | 0 | 100%
tictactoe/contest/admin | 17 | 3 | 0 | 82%
tictactoe/contest/fixtures | 7 | 0 | 0 | 100%
tictactoe/contest/forms | 6 | 0 | 0 | 100%
tictactoe/contest/logic | 20 | 8 | 0 | 60%
tictactoe/contest/migrations/0001_initial | 6 | 0 | 0 | 100%
tictactoe/contest/migrations/0002_fight | 4 | 0 | 0 | 100%
tictactoe/contest/migrations/0003_latestentry | 5 | 0 | 0 | 100%
tictactoe/contest/migrations/0004_auto_20140407_1808 | 5 | 0 | 0 | 100%
tictactoe/contest/migrations/__init__ | 0 | 0 | 0 | 100%
tictactoe/contest/models | 98 | 7 | 0 | 93%
tictactoe/contest/tasks | 41 | 0 | 0 | 100%
tictactoe/contest/templatetags/__init__ | 0 | 0 | 0 | 100%
tictactoe/contest/templatetags/contest_extras | 8 | 0 | 0 | 100%
tictactoe/contest/tests | 100 | 2 | 0 | 98%
tictactoe/contest/views | 41 | 16 | 0 | 61%
tictactoe/manage | 8 | 0 | 0 | 100%
tictactoe/settings | 43 | 0 | 0 | 100%
tictactoe/tools/__init__ | 0 | 0 | 0 | 100%
tictactoe/tools/context_processors | 3 | 0 | 0 | 100%
tictactoe/tools/management/__init__ | 0 | 0 | 0 | 100%
tictactoe/tools/management/commands/__init__ | 0 | 0 | 0 | 100%
tictactoe/tools/management/commands/import_users | 24 | 24 | 0 | 0%
tictactoe/tools/models | 14 | 7 | 0 | 50%
tictactoe/tools/testing | 6 | 1 | 0 | 83%
tictactoe/tools/validators | 9 | 0 | 0 | 100%
tictactoe/urls | 4 | 0 | 0 | 100%
tictactoe/wsgi | 7 | 7 | 0 | 0%